mark_storage_args

Function mark_storage_args 

fn mark_storage_args<'hir>(
    funcs: &[&Function<'hir>],
    hir: &'hir Hir<'hir>,
    args: &CallArgs<'hir>,
    candidates: &HashSet<VariableId>,
    writes: &mut HashSet<VariableId>,
)
For each call argument, if ANY resolved overload has a storage parameter at that position, treat the argument as a write target.